aboutsummaryrefslogtreecommitdiff
path: root/Jellyfin.Server
diff options
context:
space:
mode:
Diffstat (limited to 'Jellyfin.Server')
-rw-r--r--Jellyfin.Server/Program.cs4
-rw-r--r--Jellyfin.Server/Properties/launchSettings.json6
-rw-r--r--Jellyfin.Server/StartupOptions.cs10
3 files changed, 10 insertions, 10 deletions
diff --git a/Jellyfin.Server/Properties/launchSettings.json b/Jellyfin.Server/Properties/launchSettings.json
index d68a611c1b..53d9fe1656 100644
--- a/Jellyfin.Server/Properties/launchSettings.json
+++ b/Jellyfin.Server/Properties/launchSettings.json
@@ -3,9 +3,9 @@
"Jellyfin.Server": {
"commandName": "Project"
},
- "Jellyfin.Server (nowebcontent)": {
+ "Jellyfin.Server (nowebclient)": {
"commandName": "Project",
- "commandLineArgs": "--nowebcontent"
+ "commandLineArgs": "--nowebclient"
}
}
-} \ No newline at end of file
+}
diff --git a/Jellyfin.Server/Program.cs b/Jellyfin.Server/Program.cs
index 67251eb249..d9ca141363 100644
--- a/Jellyfin.Server/Program.cs
+++ b/Jellyfin.Server/Program.cs
@@ -490,9 +490,9 @@ namespace Jellyfin.Server
IApplicationPaths appPaths,
IConfiguration? startupConfig = null)
{
// Use the swagger API page as the default redirect path if not hosting the jellyfin-web content
var inMemoryDefaultConfig = ConfigurationOptions.DefaultConfiguration;
- if (startupConfig != null && startupConfig.NoWebContent())
+ if (startupConfig != null && !startupConfig.HostWebClient())
{
inMemoryDefaultConfig[HttpListenerHost.DefaultRedirectKey] = "swagger/index.html";
}
@@ -490,9 +490,9 @@ namespace Jellyfin.Server
IConfiguration? startupConfig = null)
{
- // Use the swagger API page as the default redirect path if not hosting the jellyfin-web content
+ // Use the swagger API page as the default redirect path if not hosting the web client
var inMemoryDefaultConfig = ConfigurationOptions.DefaultConfiguration;
diff --git a/Jellyfin.Server/StartupOptions.cs b/Jellyfin.Server/StartupOptions.cs
index 0abc0fd911..c93577d3ea 100644
--- a/Jellyfin.Server/StartupOptions.cs
+++ b/Jellyfin.Server/StartupOptions.cs
@@ -19,10 +19,10 @@ namespace Jellyfin.Server
public string? DataDir { get; set; }
/// <summary>
/// Gets or sets a value indicating whether the server should not host static web content.
/// </summary>
- [Option(ConfigurationExtensions.NoWebContentKey, Required = false, HelpText = "Indicates that the web server should not host any static web content.")]
- public bool NoWebContent { get; set; }
+ [Option("nowebclient", Required = false, HelpText = "Indicates that the web server should not host the web client.")]
+ public bool NoWebClient { get; set; }
/// <summary>
/// Gets or sets the path to the web directory.
@@ -84,9 +84,9 @@ namespace Jellyfin.Server
{
var config = new Dictionary<string, string>();
- if (NoWebContent)
+ if (NoWebClient)
{
- config.Add(ConfigurationExtensions.NoWebContentKey, bool.TrueString);
+ config.Add(ConfigurationExtensions.HostWebClientKey, bool.FalseString);
}
return config;
@@ -19,10 +19,10 @@ namespace Jellyfin.Server
public string? DataDir { get; set; }
/// <summary>
- /// Gets or sets a value indicating whether the server should not host static web content.
+ /// Gets or sets a value indicating whether the server should not host the web client.
/// </summary>